==> sagcad_0.9.6.orig.tar.gz: sagcad-0.9.6/src/Dimension.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : Dimension.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2001/02/27
 *    Last                 : 2003/04/16
 * ====================================================================
 */

#ifndef __DIMENSION_H__
#define __DIMENSION_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 :   (struct #define etc)
 * -------------------------------------------------------
 */



/* -------------------------------------------------------
 * 2 : ѿ (global)
 * -------------------------------------------------------
 */
#ifdef _DIMENSION_
#define   GLOBAL
// 
#define   GLOBAL_VAL(v)  = (v)
#else
#define   GLOBAL	extern
// ʬ̵
#define   GLOBAL_VAL(v)  /* */
#endif




#undef	GLOBAL
#undef	GLOBAL_VAL
#undef _DIMENSION_



/* -------------------------------------------------------
 * 3 : ؿ (Function)
 * -------------------------------------------------------
 */
/* ˡɽ */
int DimensionDraw(GtkWidget *widget, DIMENSION *a, int TextFrag);
int Dimension_Line_Basic(GtkWidget *widget, DIMENSION *a, int TextFrag);
int Dimension_Text_Basic(GtkWidget *widget, DIMENSION *a, int TextFrag);

/* ˡǡ׻ */
int Dimension_X_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_Y_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_P_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_A_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_R_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_D_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_HD_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_PT_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int DimensionAngleCH(float *angle, int *point);



#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __DIMENSION_H__ */
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Source               : Dimension.h
 * ====================================================================
 */

==> sagcad-0.9.11.tar.gz: sagcad-0.9.11/src/Dimension.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : Dimension.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2001/02/27
 *    Last                 : 2007/10/24
 * ====================================================================
 */

#ifndef __DIMENSION_H__
#define __DIMENSION_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 : 前処理  (struct #define etc)
 * -------------------------------------------------------
 */



/* -------------------------------------------------------
 * 2 : 外部変数 (global)
 * -------------------------------------------------------
 */
#ifdef _DIMENSION_
#define   GLOBAL
// 初期値設定
#define   GLOBAL_VAL(v)  = (v)
#else
#define   GLOBAL	extern
// 初期値設定の代入部分を無くす
#define   GLOBAL_VAL(v)  /* */
#endif




#undef	GLOBAL
#undef	GLOBAL_VAL
#undef _DIMENSION_



/* -------------------------------------------------------
 * 3 : 外部関数 (Function)
 * -------------------------------------------------------
 */
/* 寸法表示 */
int DimensionDraw(GtkWidget *widget, DIMENSION *a, int TextFrag);
int Dimension_Line_Basic(GtkWidget *widget, DIMENSION *a, int TextFrag);
int Dimension_Text_Basic(GtkWidget *widget, DIMENSION *a, int TextFrag);

/* 寸法データ計算 */
int Dimension_X_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_Y_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_P_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_A_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_R_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_D_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_HD_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int Dimension_PT_Culc(DIMENSION *a, DIMENSION_CULC PicPoint);
int DimensionAngleCH(float *angle, int *point);



#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __DIMENSION_H__ */
/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Source               : Dimension.h
 * ====================================================================
 */
